==> gschedwicons-0.1.0.tar.gz: gschedwicons-0.1.0/src/calendar_cal_cb.h <==
/* Schedwi
   Copyright (C) 2007 Herve Quatremain
     
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
     
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Library General Public License for more details.
     
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

/* calendar_cal_cb.h -- GUI functions for the calendar window */

#ifndef _CALENDAR_CAL_CB_H
#define _CALENDAR_CAL_CB_H

#include <schedwi.h>
#include <gtk/gtk.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern GtkWidget *new_dialog_cal_calendar OF((GtkTreeView *view,
				const gchar *id, const gchar *parent_id,
				int workload_date));
extern void calendar_cal_ok_clicked OF((GtkButton *button));
extern void calendar_cal_cancel_clicked OF((GtkButton *button));
extern void calendar_cal_delete_event OF((GtkWidget *widget));
extern void calendar_cal_year_prev_clicked OF((GtkButton *button));
extern void calendar_cal_year_next_clicked OF((GtkButton *button));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* calendar_cal_cb.h */

/*-----------------============== End Of File ==============-----------------*/

==> gschedwicons-0.1.2.tar.gz: gschedwicons-0.1.2/src/calendar_cal_cb.h <==
/* Schedwi
   Copyright (C) 2007 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* calendar_cal_cb.h -- GUI functions for the calendar window */

#ifndef _CALENDAR_CAL_CB_H
#define _CALENDAR_CAL_CB_H

#include <schedwi.h>
#include <gtk/gtk.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern GtkWidget *new_dialog_cal_calendar OF((GtkTreeView *view,
				const gchar *id, const gchar *parent_id,
				int workload_date));
extern void calendar_cal_ok_clicked OF((GtkButton *button));
extern void calendar_cal_cancel_clicked OF((GtkButton *button));
extern void calendar_cal_delete_event OF((GtkWidget *widget));
extern void calendar_cal_year_prev_clicked OF((GtkButton *button));
extern void calendar_cal_year_next_clicked OF((GtkButton *button));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* calendar_cal_cb.h */

/*-----------------============== End Of File ==============-----------------*/
